#!/usr/bin/env python

############################################################################
#    Copyright (C) 2004 by                                                 #
#    Stefan Brockmann (stefankjb at yahoo dot com)                         #
#    Tero Kuusela (teroajk at users dot sourceforge dot net)               #
#    Petteri Klemola (pzq at users dot sourceforge dot net)                #
#                                                                          #
#    This program is free software; you can redistribute it and/or modify  #
#    it under the terms of the GNU General Public License as published by  #
#    the Free Software Foundation; either version 2 of the License, or     #
#    (at your option) any later version.                                   #
#                                                                          #
#    This program is distributed in the hope that it will be useful,       #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
#    GNU General Public License for more details.                          #
#                                                                          #
#    You should have received a copy of the GNU General Public License     #
#    along with this program; if not, write to the                         #
#    Free Software Foundation, Inc.,                                       #
#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
############################################################################

import pygame
import os
from gfx_functions import *

class Penguin(pygame.sprite.Sprite):
    "Penguin for Tuxletics snowball throwing event"

    def __init__(self):
        pygame.sprite.Sprite.__init__(self)
        self.p_images = []
        self.p_rects = []
        self.image_id = 0

        # Load the running images to a list
        # p_images[0-6]
        for i in range(8):
            s = "snowballthrow/run%s.png" % (i+1, )
            img, rect = load_png(s)
            self.p_images.append(img)
            self.p_rects.append(rect)
            self.p_rects.append(rect)

        # Load the throwing images to a list
        # p_images[7-12]
        for i in range(5):
            s = "snowballthrow/throw%s.png" % (i+1, )
            img, rect = load_png(s)
            self.p_images.append(img)
            self.p_rects.append(rect)

        # Load the standing_small image to a list
        # p_images[13]
        for i in range(1):
            s = "snowballthrow/stand_small.png"
            img, rect = load_png(s)
            self.p_images.append(img)
            self.p_rects.append(rect)

        # Load the slipping images to a list
        # p_images[14-17]
        for i in range(4):
            s = "snowballthrow/slip%s.png" % (i+1, )
            img, rect = load_png(s)
            self.p_images.append(img)

        # Load the falling down images to a list
        # p_images[18-19]
        for i in range(2):
            s = "snowballthrow/stumble%s.png" % (i+1, )
            img, rect = load_png(s)
            self.p_images.append(img)

        self.reinit()

    def reinit(self):
        self.image = self.p_images[0]
        self.rect = self.p_rects[0]
        # We need a new rect since we want to move it around
        self.rect = self.rect.move([20, 125])   # 40, 250

    def update(self, speed):
        self.rect.move_ip([speed, 0])


    def set_visible_image(self, ind):
        self.image_id = ind
        self.image = self.p_images[ind]

    def set_position(self, x, y):
        self.rect.move_ip(x - self.rect.left, y - self.rect.top)

